@@ -33,19 +33,23 @@
 #include "typeparser.h"
 #include "typesystem.h"
 
+#include "qtcompat.h"
+
 #include <QtCore/QDebug>
 
 #include <algorithm>
 #include <limits>
 
+using namespace Qt::StringLiterals;
+
 static inline QString callOperator() { return QStringLiteral("operator()"); }
 
 QString TemplateInstance::expandCode() const
 {
     TemplateEntry *templateEntry = TypeDatabase::instance()->findTemplate(m_name);
     if (!templateEntry) {
-        const QString m = QLatin1String("<insert-template> referring to non-existing template '")
-                          + m_name + QLatin1String("'.");
+        const QString m = u"<insert-template> referring to non-existing template '"_s
+                          + m_name + u"'."_s;
         throw Exception(m);
     }
 
@@ -54,11 +58,11 @@ QString TemplateInstance::expandCode() const
         code.replace(it.key(), it.value());
     while (!code.isEmpty() && code.at(code.size() - 1).isSpace())
         code.chop(1);
-    QString result = QLatin1String("// TEMPLATE - ") + m_name + QLatin1String(" - START");
-    if (!code.startsWith(QLatin1Char('\n')))
-        result += QLatin1Char('\n');
+    QString result = u"// TEMPLATE - "_s + m_name + u" - START"_s;
+    if (!code.startsWith(u'\n'))
+        result += u'\n';
     result += code;
-    result += QLatin1String("\n// TEMPLATE - ") + m_name + QLatin1String(" - END\n");
+    result += u"\n// TEMPLATE - "_s + m_name + u" - END\n"_s;
     return result;
 }
 
@@ -92,7 +96,7 @@ void CodeSnipAbstract::purgeEmptyFragments()
 
 QRegularExpression CodeSnipAbstract::placeHolderRegex(int index)
 {
-    return QRegularExpression(QLatin1Char('%') + QString::number(index) + QStringLiteral("\\b"));
+    return QRegularExpression(u'%' + QString::number(index) + QStringLiteral("\\b"));
 }
 
 void purgeEmptyCodeSnips(QList<CodeSnip> *list)
@@ -109,10 +113,14 @@ void purgeEmptyCodeSnips(QList<CodeSnip> *list)
 // ---------------------- Modification
 QString FunctionModification::accessModifierString() const
 {
-    if (isPrivate()) return QLatin1String("private");
-    if (isProtected()) return QLatin1String("protected");
-    if (isPublic()) return QLatin1String("public");
-    if (isFriendly()) return QLatin1String("friendly");
+    if (isPrivate())
+        return u"private"_s;
+    if (isProtected())
+        return u"protected"_s;
+    if (isPublic())
+        return u"public"_s;
+    if (isFriendly())
+        return u"friendly"_s;
     return QString();
 }
 
@@ -300,7 +308,7 @@ Arguments splitParameters(QStringView paramString, QString *errorMessage)
     for (const auto &t : tokens) {
         Argument argument;
         // Check defaultValue, "int @b@=5"
-        const int equalPos = t.lastIndexOf(QLatin1Char('='));
+        const int equalPos = t.lastIndexOf(u'=');
         if (equalPos != -1) {
             const int defaultValuePos = equalPos + 1;
             argument.defaultValue =
@@ -308,14 +316,14 @@ Arguments splitParameters(QStringView paramString, QString *errorMessage)
         }
         QString typeString = (equalPos != -1 ? t.left(equalPos) : t).trimmed().toString();
         // Check @name@
-        const int atPos = typeString.indexOf(QLatin1Char('@'));
+        const int atPos = typeString.indexOf(u'@');
         if (atPos != -1) {
             const int namePos = atPos + 1;
-            const int nameEndPos = typeString.indexOf(QLatin1Char('@'), namePos);
+            const int nameEndPos = typeString.indexOf(u'@', namePos);
             if (nameEndPos == -1) {
                 if (errorMessage != nullptr) {
-                    *errorMessage = QLatin1String("Mismatched @ in \"")
-                                    + paramString.toString() + QLatin1Char('"');
+                    *errorMessage = u"Mismatched @ in \""_s
+                                    + paramString.toString() + u'"';
                 }
                 return {};
             }
@@ -358,16 +366,16 @@ AddedFunction::AddedFunctionPtr
     // Skip past "operator()(...)"
     const int parenSearchStartPos = signature.startsWith(callOperator())
         ? callOperator().size() : 0;
-    const int openParenPos = signature.indexOf(QLatin1Char('('), parenSearchStartPos);
+    const int openParenPos = signature.indexOf(u'(', parenSearchStartPos);
     if (openParenPos < 0) {
         return AddedFunctionPtr(new AddedFunction(signature.toString(),
                                                   arguments, returnType));
     }
 
     const QString name = signature.left(openParenPos).trimmed().toString();
-    const int closingParenPos = signature.lastIndexOf(QLatin1Char(')'));
+    const int closingParenPos = signature.lastIndexOf(u')');
     if (closingParenPos < 0) {
-        *errorMessage = QLatin1String("Missing closing parenthesis");
+        *errorMessage = u"Missing closing parenthesis"_s;
         return {};
     }
 
@@ -376,7 +384,7 @@ AddedFunction::AddedFunctionPtr
     const int signatureLength = signature.length();
     const int qualifierLength = signatureLength - closingParenPos - 1;
     if (qualifierLength >= 5
-        && signature.right(qualifierLength).contains(QLatin1String("const"))) {
+        && signature.right(qualifierLength).contains(u"const")) {
         isConst = true;
     }
 
@@ -385,11 +393,11 @@ AddedFunction::AddedFunctionPtr
     if (params.isEmpty() && !errorMessage->isEmpty())
         return {};
     for (const auto &p : params) {
-        TypeInfo type = p.type == QLatin1String("...")
+        TypeInfo type = p.type == u"..."
             ? TypeInfo::varArgsType() : TypeParser::parse(p.type, errorMessage);
         if (!errorMessage->isEmpty()) {
-            errorMessage->prepend(u"Unable to parse added function "_qs + signatureIn
-                                  + u": "_qs);
+            errorMessage->prepend(u"Unable to parse added function "_s + signatureIn
+                                  + u": "_s);
             return {};
         }
         arguments.append({type, p.name, p.defaultValue});
@@ -457,7 +465,7 @@ QDebug operator<<(QDebug d, const CodeSnip &s)
         if (f.instance().isNull()) {
             d << '"';
             const QString &code = f.code();
-            const auto lines = QStringView{code}.split(QLatin1Char('\n'));
+            const auto lines = QStringView{code}.split(u'\n');
             for (int i = 0, size = lines.size(); i < size; ++i) {
                 if (i)
                     d << "\\n";
@@ -511,7 +519,7 @@ ArgumentModification::ArgumentModification(ArgumentModification &&) = default;
 ArgumentModification &ArgumentModification::operator=(ArgumentModification &&) = default;
 ArgumentModification::~ArgumentModification() = default;
 
-QString ArgumentModification::modifiedType() const
+const QString &ArgumentModification::modifiedType() const
 {
     return d->modified_type;
 }
@@ -522,6 +530,11 @@ void ArgumentModification::setModifiedType(const QString &value)
         d->modified_type = value;
 }
 
+bool ArgumentModification::isTypeModified() const
+{
+    return !d->modified_type.isEmpty();
+}
+
 QString ArgumentModification::pyiType() const
 {
     return d->pyiType;
@@ -849,12 +862,12 @@ bool FunctionModification::matches(const QString &functionSignature) const
 
 bool FunctionModification::setSignature(const QString &s, QString *errorMessage)
 {
-    if (s.startsWith(QLatin1Char('^'))) {
+    if (s.startsWith(u'^')) {
         d->m_signaturePattern.setPattern(s);
         if (!d->m_signaturePattern.isValid()) {
             if (errorMessage) {
-                *errorMessage = QLatin1String("Invalid signature pattern: \"")
-                    + s + QLatin1String("\": ") + d->m_signaturePattern.errorString();
+                *errorMessage = u"Invalid signature pattern: \""_s
+                    + s + u"\": "_s + d->m_signaturePattern.errorString();
             }
             return false;
         }
